jnorlib.core

Supplementary API.

Supplementary API.
raw docstring

between?clj

(between? c lower upper)

Checks whether lower <= c <= upper is true.

Checks whether `lower <= c <= upper` is true.
sourceraw docstring

find-firstclj

(find-first pred coll)

Returns the first item from coll that matches the given pred.

Returns the first item from `coll` that matches the given `pred`.
sourceraw docstring

sliceclj

(slice start endx coll)

Retrieves a sequence from the item number start to number endx exclusive, from coll.

Retrieves a sequence from the item number `start` to number `endx`
exclusive, from `coll`.
sourceraw docstring

throws?clj

(throws? f)

Invokes the provided f to check whether it throws an exception.

Invokes the provided `f` to check whether it throws an exception.
sourceraw docstring

typedclj

(typed & pairs)

Takes pairs in the form of [Class instance] and throws if an instance does not match its associated type. Returns nil.

Takes pairs in the form of [Class instance] and throws if an instance does
not match its associated type. Returns nil.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries