Supplementary API.
Supplementary API.
(between? c lower upper)Checks whether lower <= c <= upper is true.
Checks whether `lower <= c <= upper` is true.
(find-first pred coll)Returns the first item from coll that matches the given pred.
Returns the first item from `coll` that matches the given `pred`.
(slice start endx coll)Retrieves a sequence from the item number start to number endx
exclusive, from coll.
Retrieves a sequence from the item number `start` to number `endx` exclusive, from `coll`.
(throws? f)Invokes the provided f to check whether it throws an exception.
Invokes the provided `f` to check whether it throws an exception.
(typed & pairs)Takes pairs in the form of [Class instance] and throws if an instance does not match its associated type. Returns nil.
Takes pairs in the form of [Class instance] and throws if an instance does not match its associated type. Returns nil.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |